=========
Changelog
=========

Version 0.1.1 (2023-01-23)
==========================

This is a bugfix release.

* Fix doctest: use UTC in get_time_from_bytes example by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/3
* Fix link to Bleak's BLEDevice in docs by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/4
* Add codecov badge to README by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/5
* Various documentation fixes by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/6
* Build documentation on Read The Docs with Python 3.11 by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/7
* Use Ubuntu 22.04/Python 3.11 for Read The Docs by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/8
* Update to PyScaffold v4.4 project features by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/9
* Import future annotations by @koenvervloesem in https://github.com/koenvervloesem/bluetooth-clocks/pull/10

Version 0.1.0 (2023-01-20)
==========================

Initial version of Bluetooth Clocks
